@@ -1,5 +1,5 @@
 from typing import Optional, Union, List
-from datetime import datetime
+from datetime import datetime, timedelta
 
 import pandas as pd
 
@@ -25,7 +25,7 @@ def get_data_list(
     page: Optional[int] = None,
     page_size: Optional[int] = None,
     get_all_pages: bool = True,
-    multithread_pages: bool = False,
+    multithread_pages: bool = True,
     expand_measurement: bool = True,
     extract_from_storage_unit: Optional[str] = "label",
     extract_from_tags: Optional[str] = "value",
@@ -400,8 +400,8 @@ def get_multiple_data_values(
     data_id: Optional[Union[str, List[str]]] = None,
     data_reference: Optional[Union[str, List[str]]] = None,
     number_of_values: Optional[int] = None,
-    aggregation_period: Optional[str] = None,
-    aggregation_function: Optional[str] = None,
+    aggregation_period: Optional[Union[str, timedelta, pd.Timedelta]] = None,
+    aggregation_function: Optional[Union[str, List[str]]] = None,
     unit_id: Optional[Union[str, List[str]]] = None,
     unit_label: Optional[Union[str, List[str]]] = None,
     name_data_from: str = "reference",
@@ -553,6 +553,7 @@ def insert_time_values(
     data: Union[pd.Series, pd.DataFrame],
     units: Optional[dict] = None,
     use_external_reference: bool = False,
+    timestamp_index_name: str = "timestamp",
     api_credentials: Optional[_credentials.OIAnalyticsAPICredentials] = None,
 ):
     """
@@ -566,6 +567,8 @@ def insert_time_values(
         A dictionary indexed by data reference, specifying the values in which it is sent.
     use_external_reference: bool, default False
         Whether or not the data are named using their external reference (else the OIAnalytics reference is used).
+    timestamp_index_name: str, default 'timestamp'
+        Name of the index level containing the timestamp
     api_credentials: OIAnalyticsAPICredentials, optional
         The credentials to use to query the API. If None, previously set default credentials are used.
 
@@ -588,7 +591,7 @@ def insert_time_values(
 
     try:
         data.index = (
-            data.index.get_level_values("timestamp")
+            data.index.get_level_values(timestamp_index_name)
             .to_series()
             .apply(utils.get_zulu_isoformat)
         )
