@@ -1,4 +1,4 @@
-from typing import Optional, Union
+from typing import Optional, Union, List
 from datetime import datetime, timedelta, timezone
 import dateutil
 
@@ -16,9 +16,41 @@ class TestModelExecution(_dtos.ModelExecution):
         - timedelta(hours=1),
         current_execution_instant: datetime = datetime.now(timezone.utc),
         data_exchange_mode: str = "FREE_FROM_API",
+        single_observation_type: str = "time",
+        single_observation_overlapping_period: timedelta = timedelta(hours=1),
+        single_observation_aggregation_period: str = "PT10M",
+        single_observation_batch_type_id: str = "single_obs_batch_type_id",
+        single_observation_batch_type_reference: str = "single_obs_batch_type_reference",
     ):
-        # Args validation
-        if data_exchange_mode not in ["FREE_FROM_API", "SINGLE_OBSERVATION"]:
+        # Data exchange mode
+        if data_exchange_mode == "FREE_FROM_API":
+            single_obs_context = None
+        elif data_exchange_mode == "SINGLE_OBSERVATION":
+            if single_observation_type == "time":
+                single_obs_context = _dtos.SingleObservationTimeContext(
+                    type="time",
+                    overlappingPeriod=single_observation_overlapping_period,
+                    aggregationPeriod=single_observation_aggregation_period,
+                )
+            elif single_observation_type == "batch":
+                single_obs_context = _dtos.SingleObservationBatchContext(
+                    type="batch",
+                    overlappingPeriod=single_observation_overlapping_period,
+                    batchPredicate=_dtos.BatchPredicateValue(
+                        type="batch-predicate",
+                        batchType=_dtos.BatchPredicateBatchType(
+                            type="batch-type",
+                            id=single_observation_batch_type_id,
+                            reference=single_observation_batch_type_reference,
+                        ),
+                        featureFilters=[],
+                    ),
+                )
+            else:
+                raise ValueError(
+                    f"{single_observation_type} is not valid for 'single_observation_type'"
+                )
+        else:
             raise ValueError(
                 f"{data_exchange_mode} is not valid for 'data_exchange_mode'"
             )
@@ -44,6 +76,7 @@ class TestModelExecution(_dtos.ModelExecution):
                 trigger=_dtos.CronTrigger(type="cron-trigger", cron="0 0 * * * *"),
                 active=False,
                 dataExchangeMode=data_exchange_mode,
+                singleObservationContext=single_obs_context,
                 inputParameters=[],
                 outputParameters=[],
             ),
@@ -63,6 +96,17 @@ class TestModelExecution(_dtos.ModelExecution):
         test_model_execution.pythonModelInstance = model_execution.pythonModelInstance
         return test_model_execution
 
+    def add_single_observation_feature_filter(
+        self,
+        feature_id: str = "single_obs_feature_id",
+        feature_reference: str = "single_obs_feature_reference",
+    ):
+        self.pythonModelInstance.singleObservationContext.batchPredicate.featureFilters.append(
+            _dtos.BatchTagValue(
+                type="batch-tag-value", id=feature_id, reference=feature_reference
+            )
+        )
+
     def add_string_input(
         self,
         source_code_name: str = "string_input",
@@ -119,7 +163,7 @@ class TestModelExecution(_dtos.ModelExecution):
     def add_duration_input(
         self,
         source_code_name: str = "duration_input",
-        value: Optional[str] = 86_400_000,
+        value: Optional[int] = 86_400_000,
     ):
         self.pythonModelInstance.inputParameters.append(
             _dtos.DurationParameter(
@@ -407,17 +451,57 @@ class TestModelExecution(_dtos.ModelExecution):
         source_code_name: str = "batch_predicate_input",
         batch_type_id: Optional[str] = "batch_type_id",
         batch_type_reference: str = "Batch type reference",
+        feature_value_ids: Optional[List[str]] = None,
+        feature_value_references: Optional[List[str]] = None,
     ):
         if batch_type_id is None:
             batch_predicate_value = None
         else:
+            # Build feature filters
+            if feature_value_ids is None and feature_value_references is None:
+                feature_filters = []
+            elif feature_value_ids is not None and feature_value_references is not None:
+                if len(feature_value_ids) != len(feature_value_references):
+                    raise ValueError(
+                        "'feature_value_ids' and 'feature_value_references' should have the same length"
+                    )
+                else:
+                    feature_filters = [
+                        _dtos.BatchTagValue(
+                            type="batch-tag-value",
+                            id=feature_value_ids[i],
+                            reference=feature_value_references[i],
+                        )
+                        for i in range(len(feature_value_ids))
+                    ]
+            elif feature_value_ids is not None:
+                feature_filters = [
+                    _dtos.BatchTagValue(
+                        type="batch-tag-value",
+                        id=fid,
+                        reference=f"{fid}_reference",
+                    )
+                    for fid in feature_value_ids
+                ]
+            else:
+                feature_filters = [
+                    _dtos.BatchTagValue(
+                        type="batch-tag-value",
+                        id=f"{fref}_id",
+                        reference=fref,
+                    )
+                    for fref in feature_value_references
+                ]
+
+            # Build batch predicate
             batch_predicate_value = _dtos.BatchPredicateValue(
-                type="batch-data",
+                type="batch-predicate",
                 batchType=_dtos.BatchPredicateBatchType(
-                    type="batch-predicate",
+                    type="batch-type",
                     id=batch_type_id,
                     reference=batch_type_reference,
                 ),
+                featureFilters=feature_filters,
             )
 
         self.pythonModelInstance.inputParameters.append(
